﻿//=======================================================================================
//
//  Purpose: Implement the equality comparison converter.
//
//
//  Copyright (C) 2011 Mark Stevens
//
//  Permission is hereby granted, free of charge, to any person obtaining a copy
//  of this software and associated documentation files (the "Software") to use
//  the Software in a non-commercial environment subject to the following conditions:
//
//  1.  The above copyright notice and this permission notice shall be included in
//      all copies or substantial portions of the Software.
//  2.  The original author shall be acknowledged in any software and documentation
//      including (but not restricted to) books, articles and online posts.
//
//  Use in a commercial environment is subject to the written consent of the author
//  and/or copyright holder.
//
//  The Software, documentation, instructions for use and associated materials
//  are provided "as is" without warranty of any kind express or implied.  The
//  author and copyright holders shall ihn no way be held liable for any claim
//  or damages arising as a result of the use of the software and/or documentation.
//
//=======================================================================================
using System;
using System.Windows;
using System.Windows.Data;

namespace NE555Calculator
{
    public class IsEqualConverter : IValueConverter
    {
        #region IValueConverter Members

        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            bool same;

            if (value == null)
            {
                same = false;
            }
            else
            {
                if (value.GetType() == typeof(string))
                {
                    same = string.Compare((string) value, (string) parameter, StringComparison.InvariantCultureIgnoreCase) == 0;
                }
                else
                {
                    if (value.GetType() == typeof(Component))
                    {
                        same = string.Compare(((Component) value).Name, (string) parameter, StringComparison.InvariantCultureIgnoreCase) == 0;
                    }
                    else
                    {
                        same = false;
                    }
                }
            }
            if (targetType == typeof(bool))
            {
                return (same);
            }
            else
            {
                if (same)
                {
                    return (Visibility.Visible);
                }
                else
                {
                    return (Visibility.Collapsed);
                }
            }
        }

        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotImplementedException();
        }

        #endregion
    }
}
