﻿//=======================================================================================
//
//  Purpose: Results of the calculation for the NE555 operational parameters.
//
//
//  Copyright (C) 2011 Mark Stevens
//
//  Permission is hereby granted, free of charge, to any person obtaining a copy
//  of this software and associated documentation files (the "Software") to use
//  the Software in a non-commercial environment subject to the following conditions:
//
//  1.  The above copyright notice and this permission notice shall be included in
//      all copies or substantial portions of the Software.
//  2.  The original author shall be acknowledged in any software and documentation
//      including (but not restricted to) books, articles and online posts.
//
//  Use in a commercial environment is subject to the written consent of the author
//  and/or copyright holder.
//
//  The Software, documentation, instructions for use and associated materials
//  are provided "as is" without warranty of any kind express or implied.  The
//  author and copyright holders shall ihn no way be held liable for any claim
//  or damages arising as a result of the use of the software and/or documentation.
//
//=======================================================================================

namespace NE555Calculator
{
    /// <summary>
    /// Hold a single result for the NE555 calcuation.
    /// </summary>
    public class ResultItem
    {
        /// <summary>
        /// Value for resistor R1
        /// </summary>
        public double R1 { get; set; }

        /// <summary>
        /// Value for resistor R2
        /// </summary>
        public double R2 { get; set; }

        /// <summary>
        /// Value for the capacitor C1
        /// </summary>
        public double C1 { get; set; }

        /// <summary>
        /// Amount of time the output is high.
        /// </summary>
        public double TimeHigh { get; set; }

        /// <summary>
        /// Amount of time the output is low.
        /// </summary>
        public double TimeLow { get; set; }

        /// <summary>
        /// Period of the pulse
        /// </summary>
        public double Period { get; set; }

        /// <summary>
        /// Value for the frequency.
        /// </summary>
        public double Frequency { get; set; }

        /// <summary>
        /// Value for the duty cycle
        /// </summary>
        public double DutyCycle { get; set; }
    }
}
